@@ -42,4 +42,4 @@ class BadGridError(PolytopeError, ValueError):
 
 class GribJumpNoIndexError(PolytopeError, ValueError):
     def __init__(self):
-        self.message = "GribJump index for this data was not yet written."
+        self.message = "GribJump index for this data is not yet available."
